@@ -3,6 +3,7 @@ import json
 from awesomeTaskPy.log.loger import loger
 import sys
 contextObj=None
+TASKINFOREPLACE="-|&|-"
 class Singleton(object):
     def __init__(self, cls):
         self._cls = cls
@@ -26,12 +27,18 @@ class context():
     def getLoger(self):
         return self.__log
 def getContext():
+    global contextObj
     if contextObj!=None:
         return contextObj
     return context({"taskId":"test"})
 def initContext():
+    global contextObj
+    if contextObj!=None:
+        return contextObj
     params='{"taskId":"test"}'
     if len(sys.argv)>=2:
         params=sys.argv[1]
+        global TASKINFOREPLACE
+        params=params.replace(TASKINFOREPLACE,'"')
     taskInfo=json.loads(params)
     contextObj=context(taskInfo)
